@@ -43,7 +43,7 @@ def get_pandas_df_from_db(sql_select_query):
         print(f"Get leads to work - {repr(exception)}")
     return pd.DataFrame(data)
 
-def get_data_df_from_db(sql_select_query):
+def get_data_from_db(sql_select_query):
     data = []
     try:
         data = text(sql_select_query)
@@ -54,7 +54,7 @@ def get_data_df_from_db(sql_select_query):
         print(f"- Total leads to work: {len(data)}")
     except Exception as exception:
         print(f"Get leads to work - {repr(exception)}")
-    return pd.DataFrame(data)
+    return data
 
 if __name__ == "__main__":
     connect_to_db(DB_HOST='',
